import redis
import config


class RedisPoolTools:
    selfpool=None

    @staticmethod
    def initPools(host='127.0.0.1',port=6379,password=None):
        RedisPoolTools.selfpool = redis.ConnectionPool(host=host, port=port,password=password, decode_responses=True)

    def __init__(self,sign=''):
        self.rd = redis.Redis(connection_pool=RedisPoolTools.selfpool)
        self.sign = sign

    def StringSet(self,key,val,ex=None):
        self.rd.set(self.sign+ key, val,ex=ex)
    
    def StringGet(self,key):
        return self.rd.get(self.sign + key)

    def HasSet(self,haskey,key,val,ex=None):
        self.rd.hset(self.sign + haskey,key,val,ex)

    def HasGet(self,haskey,key):
        return self.rd.hget(self.sign + haskey,key)

    # def timeout(self):
    #     self.rd.t

    def HasAll(self,name):
        return self.rd.hgetall(self.sign + name)

    def incr(self,key:str,add:int=1):
        return self.rd.incr(self.sign + key,add)

    def timeout(self,name,sec):
        self.rd.expire(self.sign + name,sec)

    def RomveKey(self,name):
        self.rd.delete(self.sign + name)

    def GetStrFromHasByte(self,hs,hname):
        try:
            return str(hs[bytes(hname, encoding = "utf8")],encoding="utf-8")
        except:
            pass
        return ''

    def DeQueue(self,name):
        return self.rd.lpop(self.sign + name)

    def EnQueue(self,name,val1):
        self.rd.lpush(self.sign + name,val1)



import http.client
import time
import os
# import tools.holiday

def get_webservertime(host='www.baidu.com'):
    conn=http.client.HTTPConnection(host)
    conn.request("GET", "/")
    r=conn.getresponse()
    #r.getheaders() #获取所有的http头
    ts=  r.getheader('date') #获取http头date部分
    #将GMT时间转换成北京时间
    ltime= time.strptime(ts[5:25], "%d %b %Y %H:%M:%S")
    # print(ltime)
    ttime=time.localtime(time.mktime(ltime)+8*60*60)
    now = time.strftime("%Y-%m-%d %H:%M:%S", ttime)
    # print(now)
    return now


# def StockRunTime():
#     isdo = False
#     nowt = time.strftime("%H%M%S", time.localtime())
#     nowt = int(nowt)
#     # 工作日
#     if tools.holiday.IsWorkDay():
#         if nowt >= 93000 and nowt <= 113000:
#             isdo = True
#         if nowt >= 130000 and nowt < 150000:
#             isdo = True
#     else:
#         print('不是工作日')

#     return isdo


import jgconfig.logtools
import time

class TestLog(object):
    def testlog(self):
        jgconfig.logtools.initOneDayLog("test")

        jgconfig.logtools
        while True:
            time.sleep(1)



# import logging
from logging.handlers import TimedRotatingFileHandler as TimedRotatingFileHandler123
# from logging.handlers import RotatingFileHandler

import logging
import datetime
import sys

# logger.debug('debug message')
# logger.info('info message')
# logger.warning('warn message')
# logger.error('error message')
# logger.critical('critical message')

logger = logging.getLogger()


class LogLevel:
    CRITICAL = 50
    FATAL = CRITICAL
    ERROR = 40
    WARNING = 30
    WARN = WARNING
    INFO = 20
    DEBUG = 10
    NOTSET = 0

def initLog1(logname='log.txt',when='D',clevel=10,flevle=10,dlevle=20):

    # logger = logging.getLogger('mylogger')
    logger.setLevel(dlevle)
    rf_handler = logging.StreamHandler(sys.stderr)#默认是sys.stderr
    rf_handler.setLevel(clevel) 
    rf_handler.setFormatter(logging.Formatter("%(asctime)s - %(name)s - %(message)s"))
    
    f_handler = TimedRotatingFileHandler123(logname, when=when, encoding="utf-8",interval=1, backupCount=7)
    f_handler.setLevel(flevle)
    f_handler.setFormatter(logging.Formatter("%(asctime)s - %(levelname)s - %(filename)s[:%(lineno)d] - %(message)s"))
    
    logger.addHandler(rf_handler)
    logger.addHandler(f_handler)
    
    logger.debug('debug message')
    logger.info('info message')
    logger.warning('warning message')
    logger.error('error message')
    logger.critical('critical message')






# def initOneDayLog(logpath='logs/log.txt',LogLevel:int = 20):
#     # logger = logging.getLogger(name1)
#     logger.setLevel(LogLevel)
#     ch = TimedRotatingFileHandler(logpath, when='H', encoding="utf-8")
#     ch.setLevel(LogLevel)
#     formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
#     ch.setFormatter(formatter)
#     logger.addHandler(ch)
#     logger.info('start server')
#     return logger




import requests
import json


def httpget(url, paramsDict=None):
    '''
    http get
    '''
    if paramsDict is None:
        response = requests.get(url=url)
        return response.text
    response = requests.get(url=url, params=paramsDict)
    return response.text


def httppost_form(url, data):
    '''
    http post application/x-www-form-urlencoded

    - par:
        - url str
        - data dict
    '''
    response = requests.post(url=url, data=data, headers={
                             'Content-Type': 'application/x-www-form-urlencoded'})
    return response.text


def httppost_json(url, data):
    '''
    http post application/json

    - par:
        - url str
        - data dict
    '''
    response = requests.post(url=url, data=json.dumps(data), headers={
                             'Content-Type': 'application/json'})
    return response.text


def httppost_xml(url, xml):
    '''
    http post text/xml

    - par:
        - url str
        - xml str <?xml  ?>
    '''
    response = requests.post(url=url,data=xml,headers={'Content-Type':'text/xml'})
    return response.text
